@@ -11,7 +11,6 @@ from collections import defaultdict
 from imp import load_source
 from shutil import copy
 from shutil import copyfile
-from shutil import copystat
 from shutil import copytree
 from tempfile import mkdtemp
 
@@ -27,9 +26,8 @@ from .helpers import read
 from .helpers import timestamp
 from .helpers import LambdaContext
 
+
 ARN_PREFIXES = {
-    'cn-north-1': 'aws-cn',
-    'cn-northwest-1': 'aws-cn',
     'us-gov-west-1': 'aws-us-gov',
 }
 
@@ -59,11 +57,10 @@ def cleanup_old_versions(
         profile_name = cfg.get('profile')
         aws_access_key_id = cfg.get('aws_access_key_id')
         aws_secret_access_key = cfg.get('aws_secret_access_key')
-        aws_session_token = cfg.get('aws_session_token')
 
         client = get_client(
             'lambda', profile_name, aws_access_key_id, aws_secret_access_key,
-            region=cfg.get('region'), aws_session_token=aws_session_token
+            cfg.get('region'),
         )
 
         response = client.list_versions_by_function(
@@ -87,9 +84,9 @@ def cleanup_old_versions(
 
 
 def deploy(
-    src, requirements=None, local_package=None,
-    config_file='config.yaml', profile_name=None,
-    preserve_vpc=False, preserve_variables=False
+        src, requirements=None, local_package=None,
+        config_file='config.yaml', profile_name=None,
+        preserve_vpc=False
 ):
     """Deploys a new function to AWS Lambda.
 
@@ -116,8 +113,7 @@ def deploy(
 
     existing_config = get_function_config(cfg)
     if existing_config:
-        update_function(cfg, path_to_zip_file, existing_config, preserve_vpc=preserve_vpc,
-                        preserve_variables=preserve_variables)
+        update_function(cfg, path_to_zip_file, existing_config, preserve_vpc=preserve_vpc)
     else:
         create_function(cfg, path_to_zip_file)
 
@@ -160,8 +156,8 @@ def deploy_s3(
 
 
 def upload(
-    src, requirements=None, local_package=None,
-    config_file='config.yaml', profile_name=None,
+        src, requirements=None, local_package=None,
+        config_file='config.yaml', profile_name=None,
 ):
     """Uploads a new function to AWS S3.
 
@@ -235,7 +231,7 @@ def invoke(
 
     timeout = cfg.get('timeout')
     if timeout:
-        context = LambdaContext(cfg.get('function_name'), timeout)
+        context = LambdaContext(cfg.get('function_name'),timeout)
     else:
         context = LambdaContext(cfg.get('function_name'))
 
@@ -356,7 +352,6 @@ def build(
 
             # Copy handler file into root of the packages folder.
             copyfile(f, os.path.join(path_to_temp, filename))
-            copystat(f, os.path.join(path_to_temp, filename))
         elif os.path.isdir(f):
             destination_folder = os.path.join(path_to_temp, f[len(src) + 1:])
             copytree(f, destination_folder)
@@ -409,20 +404,17 @@ def _install_packages(path, packages):
     :param list packages:
         A list of packages to be installed via pip.
     """
-
     def _filter_blacklist(package):
         blacklist = ['-i', '#', 'Python==', 'python-lambda==']
         return all(package.startswith(entry) is False for entry in blacklist)
-
     filtered_packages = filter(_filter_blacklist, packages)
     for package in filtered_packages:
         if package.startswith('-e '):
             package = package.replace('-e ', '')
 
         print('Installing {package}'.format(package=package))
-        subprocess.check_call(
-            [sys.executable, '-m', 'pip', 'install', package, '-t', path, '--ignore-installed'])
-    print('Install directory contents are now: {directory}'.format(directory=os.listdir(path)))
+        subprocess.check_call([sys.executable, '-m', 'pip', 'install', package, '-t', path, '--ignore-installed'])
+    print ('Install directory contents are now: {directory}'.format(directory=os.listdir(path)))
 
 
 def pip_install_to_target(path, requirements=None, local_package=None):
@@ -442,7 +434,7 @@ def pip_install_to_target(path, requirements=None, local_package=None):
     packages = []
     if not requirements:
         print('Gathering pip packages')
-        pkgStr = subprocess.check_output([sys.executable, '-m', 'pip', 'freeze'])
+        pkgStr = subprocess.check_call([sys.executable, '-m', 'pip', 'freeze'])
         packages.extend(pkgStr.decode('utf-8').splitlines())
     else:
         if os.path.exists(requirements):
@@ -469,19 +461,19 @@ def get_role_name(region, account_id, role):
 
 def get_account_id(
     profile_name, aws_access_key_id, aws_secret_access_key,
-    region=None, aws_session_token=None
+    region=None,
 ):
     """Query STS for a users' account_id"""
     client = get_client(
         'sts', profile_name, aws_access_key_id, aws_secret_access_key,
-        region=region, aws_session_token=aws_session_token
+        region,
     )
     return client.get_caller_identity().get('Account')
 
 
 def get_client(
     client, profile_name, aws_access_key_id, aws_secret_access_key,
-    region=None, aws_session_token=None
+    region=None,
 ):
     """Shortcut for getting an initialized instance of the boto3 client."""
 
@@ -489,7 +481,7 @@ def get_client(
         profile_name=profile_name,
         aws_access_key_id=aws_access_key_id,
         aws_secret_access_key=aws_secret_access_key,
-        region_name=region, aws_session_token=aws_session_token
+        region_name=region,
     )
     return boto3.client(client)
 
@@ -502,11 +494,11 @@ def create_function(cfg, path_to_zip_file, use_s3=False, s3_file=None):
     profile_name = cfg.get('profile')
     aws_access_key_id = cfg.get('aws_access_key_id')
     aws_secret_access_key = cfg.get('aws_secret_access_key')
-    aws_session_token = cfg.get('aws_session_token')
+
     account_id = get_account_id(
-        profile_name, aws_access_key_id, aws_secret_access_key, region=cfg.get(
+        profile_name, aws_access_key_id, aws_secret_access_key, cfg.get(
             'region',
-        ), aws_session_token=aws_session_token
+        ),
     )
     role = get_role_name(
         cfg.get('region'), account_id,
@@ -515,7 +507,7 @@ def create_function(cfg, path_to_zip_file, use_s3=False, s3_file=None):
 
     client = get_client(
         'lambda', profile_name, aws_access_key_id, aws_secret_access_key,
-        region=cfg.get('region'), aws_session_token=aws_session_token
+        cfg.get('region'),
     )
 
     # Do we prefer development variable over config?
@@ -537,7 +529,7 @@ def create_function(cfg, path_to_zip_file, use_s3=False, s3_file=None):
                 'S3Bucket': '{}'.format(buck_name),
                 'S3Key': '{}'.format(s3_file),
             },
-            'Description': cfg.get('description', ''),
+            'Description': cfg.get('description'),
             'Timeout': cfg.get('timeout', 15),
             'MemorySize': cfg.get('memory_size', 512),
             'VpcConfig': {
@@ -553,7 +545,7 @@ def create_function(cfg, path_to_zip_file, use_s3=False, s3_file=None):
             'Role': role,
             'Handler': cfg.get('handler'),
             'Code': {'ZipFile': byte_stream},
-            'Description': cfg.get('description', ''),
+            'Description': cfg.get('description'),
             'Timeout': cfg.get('timeout', 15),
             'MemorySize': cfg.get('memory_size', 512),
             'VpcConfig': {
@@ -584,15 +576,9 @@ def create_function(cfg, path_to_zip_file, use_s3=False, s3_file=None):
 
     client.create_function(**kwargs)
 
-    concurrency = get_concurrency(cfg)
-    if concurrency > 0:
-        client.put_function_concurrency(FunctionName=func_name,
-                                        ReservedConcurrentExecutions=concurrency)
-
 
 def update_function(
-    cfg, path_to_zip_file, existing_cfg, use_s3=False, s3_file=None, preserve_vpc=False,
-    preserve_variables=False
+        cfg, path_to_zip_file, existing_cfg, use_s3=False, s3_file=None, preserve_vpc=False
 ):
     """Updates the code of an existing Lambda function"""
 
@@ -601,11 +587,11 @@ def update_function(
     profile_name = cfg.get('profile')
     aws_access_key_id = cfg.get('aws_access_key_id')
     aws_secret_access_key = cfg.get('aws_secret_access_key')
-    aws_session_token = cfg.get('aws_session_token')
 
     account_id = get_account_id(
-        profile_name, aws_access_key_id, aws_secret_access_key, region=cfg.get('region'),
-        aws_session_token=aws_session_token
+        profile_name, aws_access_key_id, aws_secret_access_key, cfg.get(
+            'region',
+        ),
     )
     role = get_role_name(
         cfg.get('region'), account_id,
@@ -614,7 +600,7 @@ def update_function(
 
     client = get_client(
         'lambda', profile_name, aws_access_key_id, aws_secret_access_key,
-        region=cfg.get('region'), aws_session_token=aws_session_token
+        cfg.get('region'),
     )
 
     # Do we prefer development variable over config?
@@ -641,7 +627,7 @@ def update_function(
         'Role': role,
         'Runtime': cfg.get('runtime'),
         'Handler': cfg.get('handler'),
-        'Description': cfg.get('description', ''),
+        'Description': cfg.get('description'),
         'Timeout': cfg.get('timeout', 15),
         'MemorySize': cfg.get('memory_size', 512),
     }
@@ -660,39 +646,20 @@ def update_function(
             'SubnetIds': cfg.get('subnet_ids', []),
             'SecurityGroupIds': cfg.get('security_group_ids', []),
         }
-    if preserve_variables:
-        kwargs['Environment'] = existing_cfg.get('Configuration', {}).get('Environment')
-        if kwargs['Environment'] is None and 'environment_variables' in cfg:
-            kwargs.update(
-                Environment={
-                    'Variables': {
-                        key: str(get_environment_variable_value(value))
-                        for key, value
-                        in cfg.get('environment_variables').items()
-                    },
+
+    if 'environment_variables' in cfg:
+        kwargs.update(
+            Environment={
+                'Variables': {
+                    key: str(get_environment_variable_value(value))
+                    for key, value
+                    in cfg.get('environment_variables').items()
                 },
-            )
-    else:
-        if 'environment_variables' in cfg:
-            kwargs.update(
-                Environment={
-                    'Variables': {
-                        key: str(get_environment_variable_value(value))
-                        for key, value
-                        in cfg.get('environment_variables').items()
-                    },
-                },
-            )
+            },
+        )
 
     ret = client.update_function_configuration(**kwargs)
 
-    concurrency = get_concurrency(cfg)
-    if concurrency > 0:
-        client.put_function_concurrency(FunctionName=cfg.get('function_name'),
-                                        ReservedConcurrentExecutions=concurrency)
-    elif 'Concurrency' in existing_cfg:
-        client.delete_function_concurrency(FunctionName=cfg.get('function_name'))
-
     if 'tags' in cfg:
         tags = {
             key: str(value)
@@ -712,10 +679,9 @@ def upload_s3(cfg, path_to_zip_file, *use_s3):
     profile_name = cfg.get('profile')
     aws_access_key_id = cfg.get('aws_access_key_id')
     aws_secret_access_key = cfg.get('aws_secret_access_key')
-    aws_session_token = cfg.get('aws_session_token')
     client = get_client(
         's3', profile_name, aws_access_key_id, aws_secret_access_key,
-        region=cfg.get('region'), aws_session_token=aws_session_token
+        cfg.get('region'),
     )
     byte_stream = b''
     with open(path_to_zip_file, mode='rb') as fh:
@@ -753,10 +719,9 @@ def get_function_config(cfg):
     profile_name = cfg.get('profile')
     aws_access_key_id = cfg.get('aws_access_key_id')
     aws_secret_access_key = cfg.get('aws_secret_access_key')
-    aws_session_token = cfg.get('aws_session_token')
     client = get_client(
         'lambda', profile_name, aws_access_key_id, aws_secret_access_key,
-        region=cfg.get('region'), aws_session_token=aws_session_token
+        cfg.get('region'),
     )
 
     try:
@@ -766,14 +731,8 @@ def get_function_config(cfg):
             return False
 
 
-def get_concurrency(cfg):
-    """Return the Reserved Concurrent Executions if present in the config"""
-    concurrency = int(cfg.get('concurrency', 0))
-    return max(0, concurrency)
-
-
 def read_cfg(path_to_config_file, profile_name):
-    cfg = read(path_to_config_file, loader=yaml.full_load)
+    cfg = read(path_to_config_file, loader=yaml.load)
     if profile_name is not None:
         cfg['profile'] = profile_name
     elif 'AWS_PROFILE' in os.environ:
